//! Util traits to get info from types in [`crate::types`].

use crate::types::{Block, ModuleBlockElements, Register};

pub(crate) trait GetName {
    fn get_name(&self) -> String;
}

impl GetName for ModuleBlockElements {
    fn get_name(&self) -> String {
        match self {
            ModuleBlockElements::Block(block) => block.get_name(),
            ModuleBlockElements::Register(register) => register.get_name(),
            ModuleBlockElements::Memory(memory) => todo!(),
            ModuleBlockElements::Fifo(fifo) => todo!(),
        }
    }
}

impl GetName for Block {
    fn get_name(&self) -> String {
        self.name.clone()
    }
}

impl GetName for Register {
    fn get_name(&self) -> String {
        self.name.clone()
    }
}
